@@ -5,7 +5,7 @@ from struct import unpack, pack
 from pathlib import Path
 
 import gi
-gi.require_version('Hinawa', '2.0')
+gi.require_version('Hinawa', '3.0')
 from gi.repository import Hinawa
 
 from hinawa_utils.bebob.maudio_protocol_abstract import MaudioProtocolAbstract
@@ -137,7 +137,7 @@ class MaudioProtocolSpecial(MaudioProtocolAbstract):
                 req.transaction(self.unit.get_node(), tcode,
                                 self.BASE_ADDR + offset, len(data), data)
                 break
-            except Exception as e:
+            except Exception:
                 if count > 10:
                     raise OSError('Fail to communicate to the unit.')
                 count += 1
